; INITIALIZATION
; find out hardware map
HWN I
:query_loop
SUB I, 1
HWQ I
IFE B, 0x7349
  IFE A, 0xf615
    SET [monitor_n], I
IFE B, 0x12d0
  IFE A, 0xb402
    SET [clock_n], I
IFE B, 0x0206
  IFE A, 0x0001
    SET [spkr_n], I
IFN I, 0
  SET PC, query_loop

; set up the fontmaps for the images:
SET X, 0
SET I, images
:fontload_l1
SET Y, X
SHL Y, 8
ADD Y, fontmaps
SET A, 4
SET B, Y
HWI [monitor_n]
SET J, 0
SET Z, 0
:fontload_l2
SET A, Y
ADD A, J
STI [A], [I]
ADD Z, 1
IFE J, 0x40
  SET J, 0x44
IFE J, 0x4e
  SET J, 0x50
IFE J, 0x58
  SET J, 0x5e
IFE J, 0x60
  SET J, 0x76
IFE J, 0x78
  SET J, 0x7a
IFE J, 0x7c
  SET J, 0x7e
IFE J, 0x82
  SET J, 0xb6
IFE J, 0xc2
  SET J, 0xf6
IFG 106, Z
  SET PC, fontload_l2
ADD X, 1
IFG 11, X
  SET PC, fontload_l1

; set up monitor
SET A, 0
SET B, 0x8000
HWI [monitor_n]
; set fontmap:
SET A, 1
SET B, fontmaps
HWI [monitor_n]
; custom palette
SET A, 2
SET B, palette
HWI [monitor_n]
; draw "image":
SET [0x80c2], 0x1000
SET [0x80c3], 0x1001
SET [0x80c9], 0x1002
SET I, 0
SET J, 3
:initial_image_loop
SET A, J
BOR A, 0xf000
STI [0x80e0+I], A
SET A, I
AND A, 0x1f
IFE A, 10
  ADD I, 22
; skip reserved characters (refer to IMAGES below)
IFE J, 0x20
  SET J, 0x22
IFE J, 0x27
  SET J, 0x28
IFE J, 0x2c
  SET J, 0x2f
IFE J, 0x30
  SET J, 0x3b
IFE J, 0x3c
  SET J, 0x3d
IFE J, 0x3e
  SET J, 0x3f
IFE J, 0x41
  SET J, 0x5b
IFE J, 0x61
  SET J, 0x7b
IFG 0xa0, I
  SET PC, initial_image_loop


; set up clock
SET A, 0
SET B, 4
HWI [clock_n]
SET A, 2
SET B, 1
HWI [clock_n]

; enable interrupts
IAS int_handler

; MAIN PROGRAM

; Lyrics Printing
; Main registers:
;  C:  Current lyrics word (special code or ASCII character)
;  I:  Lyrics text pointer
;  J:  Screen cursor pointer
;  Z:  Delay duration
SET I, lyrics
SET J, 0x80a0
SET Z, 0

:lyrics_print_loop
SET C, [I]
ADD I, 1
; check for special codes:
SET B, C
AND B, 0xff00  ; get code
SET A, C
AND A, 0x00ff  ; get argument (image index, delay length)
IFN C, 0x000a  ; newline
  SET PC, lyrics_code_newline_end
JSR scroll_lyrics
SET J, 0x80a0  ; reset screen cursor
SET PC, lyrics_print_loop
:lyrics_code_newline_end
IFN B, 0x0100  ; draw image
  SET PC, lyrics_code_draw_end
JSR draw_image
SET PC, lyrics_print_loop
:lyrics_code_draw_end
IFN B, 0x0200  ; wait for signal
  SET PC, lyrics_code_wait_end
:wait_for_printsignal
IFE [var_printsignals], 0
  SET PC, wait_for_printsignal
SUB [var_printsignals], 1
SET PC, lyrics_print_loop
:lyrics_code_wait_end
IFN B, 0x0300  ; set delay
  SET PC, lyrics_code_delay_end
SET Z, A
SHL Z, 7
SET PC, lyrics_print_loop
:lyrics_code_delay_end
IFE C, 0xff00  ; end of lyrics
  SET PC, program_end

; If we are here, we should print the character to the screen.
; Set color:
BOR C, 0xf000
SET [J], C
ADD J, 1

; Delay:
SET A, Z
JSR delay

SET PC, lyrics_print_loop

:program_end
SUB PC, 1


:int_handler
SET PUSH, B
SET PUSH, C
SET PUSH, I
SET PUSH, J

; Play Melody:
; skip this turn if we're pausing:
IFE [var_melody_pausing], 0
  SET PC, melodyplay_process
SUB [var_melody_pausing], 1
; turn off speaker if we're one step before the next one:
IFN [var_melody_pausing], 0
  SET PC, melodyplay_end
SET A, 0
SET B, 0
HWI [spkr_n]
SET PC, melodyplay_end
:melodyplay_process
SET I, [var_melody_idx]
SET C, [melody+I]
; check for codes:
IFN C, 0x0200  ; send signal
  SET PC, melodyplay_sendsignal_end
ADD [var_printsignals], 1
ADD [var_melody_idx], 1
SET PC, melodyplay_process
:melodyplay_sendsignal_end
IFN C, 0xff00  ; end
  SET PC, melodyplay_play
; if we're finishing, stop speaker
SET A, 0
SET B, 0
HWI [spkr_n]
SET PC, melodyplay_end
:melodyplay_play
; play note:
SET A, 0
SET B, C
SHR B, 8
IFE B, 0xff  ; 0xff means pause
  SET PC, melodyplay_pause
SET B, [freq_table+B]
SET PC, melodyplay_notpause
:melodyplay_pause
SET B, 0
:melodyplay_notpause
HWI [spkr_n]
; set pause:
AND C, 0xff
SUB C, 1
SET [var_melody_pausing], C
; progress music:
ADD [var_melody_idx], 1
:melodyplay_end

; Play Bass:
; skip this turn if we're pausing:
IFE [var_bass_pausing], 0
  SET PC, bassplay_process
SUB [var_bass_pausing], 1
; turn off speaker if we're one step before the next one:
IFN [var_bass_pausing], 0
  SET PC, bassplay_end
SET A, 1
SET B, 0
HWI [spkr_n]
SET PC, bassplay_end
:bassplay_process
SET I, [var_bass_idx]
SET C, [bass+I]
; check for code:
IFN C, 0xff00  ; end
  SET PC, bassplay_play
; if we're finishing, stop speaker
SET A, 1
SET B, 0
HWI [spkr_n]
SET PC, bassplay_end
:bassplay_play
; play note:
SET A, 1
SET B, C
SHR B, 8
IFE B, 0xff  ; 0xff means pause
  SET PC, bassplay_pause
SET B, [freq_table+B]
SET PC, bassplay_notpause
:bassplay_pause
SET B, 0
:bassplay_notpause
HWI [spkr_n]
; set pause:
AND C, 0xff
SUB C, 1
SET [var_bass_pausing], C
; progress music:
ADD [var_bass_idx], 1
:bassplay_end

; Credits Printing:
; only print new line every few interrupts:
ADD [var_credits_timer], 1
IFL [var_credits_timer], 22
  SET PC, int_handler_end
SET [var_credits_timer], 0
; print a new line of credits:
IFE [var_credits_idx], -1
  SET PC, int_handler_end
JSR scroll_credits
SET I, [var_credits_idx]
SET J, 0x816b
:creditprint_loop
SET C, [credits+I]
IFN C, 0xff00  ; end of credits
  SET PC, creditprint_end_end
SET [var_credits_idx], -1
SET PC, int_handler_end
:creditprint_end_end
IFN C, 0x000a
  SET PC, creditprint_newline_end
ADD I, 1
SET [var_credits_idx], I
SET PC, int_handler_end
:creditprint_newline_end
BOR C, 0x1000
STI [J], C
SET PC, creditprint_loop
:int_handler_end
SET J, POP
SET I, POP
SET C, POP
SET B, POP
RFI 0


; GLOBAL VARIABLES
:var_bass_idx
DAT 0
:var_bass_pausing
DAT 0
:var_melody_idx
DAT 0
:var_melody_pausing
DAT 0
; Number of printsignals sent by music generator which haven't been
; processed by the printing loop yet:
:var_printsignals
DAT 0
:var_credits_timer
DAT 0
:var_credits_idx
DAT 0


; Scroll the top part of the screen with the lyrics
:scroll_lyrics
SET PUSH, I
SET I, 0x8000
:scroll_lyrics_loop
IFG 0x80a0, I
  SET PC, scroll_lyrics_l1
SET [I], 0  ; fill bottom row with null instead of "next" row
SET PC, scroll_lyrics_l2
:scroll_lyrics_l1
SET [I], [0x20+I]
:scroll_lyrics_l2
ADD I, 1
IFG 0x80c0, I
  SET PC, scroll_lyrics_loop
SET I, POP
SET PC, POP


; Scroll the bottom right part of the screen with the credits
:scroll_credits
SET PUSH, A
SET PUSH, I
SET I, 0x80ea
:scroll_credits_loop
IFG 0x8160, I
  SET PC, scroll_credits_l1
SET [I], 0  ; fill bottom row with null instead of "next" row
SET PC, scroll_credits_l2
:scroll_credits_l1
SET [I], [0x20+I]
:scroll_credits_l2
ADD I, 1
SET A, I
AND A, 0x1f
IFE A, 0
  ADD I, 11
IFG 0x8180, I
  SET PC, scroll_credits_loop
SET I, POP
SET A, POP
SET PC, POP


; Delay for amount given in A
:delay
SET PUSH, A
:delay_loop
SUB A, 1
IFE EX, 0
  SET PC, delay_loop
SET A, POP
SET PC, POP


; Draw image no. A to the bottom (just change the fontmap actually)
:draw_image
SET PUSH, A
SET PUSH, B
SET B, fontmaps
SHL A, 8
ADD B, A
SET A, 1
HWI [monitor_n]
SET B, POP
SET A, POP
SET PC, POP


; MUSIC
; Here are the codes for the musical notes:
;  0x0200:  Send signal to lyrics printing code (synchronization, melody only)
;  0xff00:  End of music
;  0xyyzz:  Play note with pitch yy (see frequency table below; 0xff means
;           pause) and duration 1/32*zz, zz != 0
:melody
; pause
DAT 0xff24
; This was a triumph.
DAT 0x200, 0x1f04, 0x1e04, 0x1c04, 0x1c04, 0x1e04, 0xff28
; I'm making a note here: HUGE SUCCESS.
DAT 0x200, 0x1504, 0x1f04, 0x1e04, 0x1c04, 0x1c08, 0x1e08, 0xff04
DAT 0x200, 0x1a08, 0x1c04, 0x1508, 0xff18
; It's hard to overstate my satisfaction.
DAT 0x200, 0x1504, 0x1c08, 0x1e04, 0x1f0c, 0x1c04, 0x1908
DAT 0x200, 0x1a0c, 0x1c08, 0x1504, 0x1508, 0x1e08, 0xff24
; Aperture Science
DAT 0x200, 0x1f04, 0x1e04, 0x1c04, 0x1c04, 0x1e04, 0xff28
; We do what we must because we can.
DAT 0x200, 0x1504, 0x1f04, 0x1e04, 0x1c04, 0x1c04, 0xff08
DAT 0x200, 0x1e04, 0x1a04, 0xff08, 0x1c04, 0x1504, 0xff20
; For the good of all of us
DAT 0x200, 0x1c08, 0x1e04, 0x1f0c, 0x1c04, 0x190c, 0x1a04, 0x1c04, 0xff04
; except the ones who are dead.
DAT 0x200, 0x1504, 0x1a04, 0x1c04 0x1d04, 0x1c04, 0x1a04, 0x1804, 0xff08
; But there's no sense crying over ev'ry mistake.
DAT 0x200, 0x1504, 0x1604, 0x1808, 0x1d08
DAT 0x1c04, 0x1a04, 0x1a04, 0x1804, 0x1a04, 0x1804, 0x1808, 0x1808
; You just keep on trying 'till you run out of cake.
DAT 0x200, 0x1504, 0x1604, 0x1808, 0x1d08, 0x1f04, 0x1d04
DAT 0x1c04, 0x1a04, 0x1a04, 0x1c04, 0x1d08, 0x1d04, 0xff04
; And the Science gets done, and you make a neat gun
DAT 0x200, 0x1f04, 0x2104, 0x2204, 0x2204, 0x2108, 0x1f08
DAT 0x1d04, 0x1f04, 0x2104, 0x2104, 0x1f08, 0x1d08
; for the people who are still alive.
DAT 0x1a04, 0x1804, 0x1a04, 0x1d04, 0x1d04, 0x1c08, 0x1c04, 0x1e04, 0x1e08
DAT 0xff68
; I'm not even angry.
DAT 0x200, 0x1504, 0x1f04, 0x1e04, 0x1c04, 0x1c08, 0x1e08, 0xff24
; I'm being so sincere right now.
DAT 0x200, 0x1f04, 0x1e04, 0x1c04, 0x1c0c, 0x1e04, 0x1a08, 0x1c08, 0x1508
DAT 0xff1c
; Even though you broke by heart and killed me.
DAT 0x200, 0x1c08, 0x1e04, 0x1f0c, 0x1c08, 0x1908, 0x1a04, 0x1c08, 0xff04
DAT 0x200, 0x1504, 0x1508, 0x1e08, 0xff20
; And tore me to pieces.
DAT 0x200, 0x1504, 0x1f04, 0x1e04, 0x1c04, 0x1c04, 0x1e04, 0xff28
; And threw ev'ry piece into a fire.
DAT 0x200, 0x1504, 0x1f04, 0x1e04, 0x1c04, 0x1c04, 0xff08
DAT 0x1e04, 0x1a04, 0xff08, 0x1c04, 0x1504, 0xff20
; As they burned it hurt because
DAT 0x200, 0x1c08, 0x1e04, 0x1f0c, 0x1c08, 0x1908, 0x1a04, 0x1c08
; I was so happy for you.
DAT 0x200, 0x1504, 0x1a04, 0x1c04, 0x1d04, 0x1c04, 0x1a04, 0x1804, 0xff08
; Now these points of data make a beautiful line.
DAT 0x200, 0x1504, 0x1604, 0x1808, 0x1d08
DAT 0x1c04, 0x1a04, 0x1a04, 0x1804, 0x1a04, 0x1804, 0x1808, 0x1808
; And we're out of beta
DAT 0x200, 0x1504, 0x1604, 0x1808, 0x1d08, 0x1f04, 0x1d04
; we're releasing on time.
DAT 0x200, 0x1c04, 0x1a04, 0x1a04, 0x1c04, 0x1d08, 0x1d04, 0xff04
; So I'm GLaD. I got burned.
DAT 0x200, 0x1f04, 0x2104, 0x2204, 0x2204, 0x2108, 0x1f08
; Think of all the things we learned
DAT 0x200, 0x1d04, 0x1f04, 0x2104, 0x2104, 0x1f04, 0x1d04, 0x1d08
; for the people who are still alive.
DAT 0x200, 0x1a04, 0x1804, 0x1a04, 0x1d04, 0x1d04, 0x1c08, 0x1c04, 0x1e04, 0x1e08
DAT 0xff6c
; Go ahead and leave me.
DAT 0x200, 0x1f04, 0x1e04, 0x1c04, 0x1c08, 0x1e08, 0xff20
; I think I prefer to stay inside.
DAT 0x200, 0x1504, 0x1f04, 0x1e04, 0x1c04, 0x1c04, 0xff08
DAT 0x1e04, 0x1a04, 0xff08, 0x1c04, 0x1504
DAT 0xff20
; Maybe you'll find someone else to help you.
DAT 0x200, 0x1c08, 0x1e04, 0x1f0c, 0x1c08, 0x1908, 0x1a04, 0x1c08, 0xff04
DAT 0x200, 0x1504, 0x1508, 0x1e08, 0xff24
; Maybe Black Mesa...
DAT 0x200, 0x1f04, 0x1e04, 0x1c04, 0x1c08, 0x1e04, 0xff28
; That was a joke, ha-ha, fat chance.
DAT 0x200, 0x1f04, 0x1e04, 0x1c04, 0x1c04, 0xff08
DAT 0x1e04, 0x1a04, 0xff08, 0x200, 0x1c04, 0x1504, 0xff20
; Anyway this cake is great.
DAT 0x200, 0x1c08, 0x1e04, 0x1f0c, 0x1c08, 0x1908, 0x1a04, 0x1c08
; It's so delicious and moist.
DAT 0x200, 0x1504, 0x1a04, 0x1c04, 0x1d04, 0x1c04, 0x1a04, 0x1804, 0xff08
; Look at me still talking when there's Science to do.
DAT 0x200, 0x1504, 0x1604, 0x1808, 0x1d08
DAT 0x1c04, 0x1a04, 0x200, 0x1a04, 0x1804, 0x1a04, 0x1804, 0x1808, 0x1808
; When I look out there
DAT 0x200, 0x1504, 0x1604, 0x1808, 0x1d08, 0x1f04
; it makes me GLaD I'm not you.
DAT 0x200, 0x1d04, 0x1c04, 0x1a04, 0x1a04, 0x1c04, 0x1d08, 0x1d04, 0xff04
; I've experiments to run.
DAT 0x200, 0x1f04, 0x2104, 0x2204, 0x2204, 0x2104, 0x1f04, 0x1f08
; There is research to be done
DAT 0x200, 0x1d04, 0x1f04, 0x2104, 0x2104, 0x1f04, 0x1d04, 0x1d08
; on the people who are still alive.
DAT 0x200, 0x1a04, 0x1804, 0x1a04, 0x1d04, 0x1d04, 0x1c08, 0x1c04, 0x1e04, 0x1e08
DAT 0xff10
; And believe me I am still alive.
DAT 0x200, 0x2104,0x2104,0x2104, 0x2304,0x2104,0x1e04,0x1a08
DAT 0x1c04,0x1e04,0x1e04, 0xff14
; I'm doing Science and I'm still alive.
DAT 0x200, 0x2104,0x2104,0x2104, 0x2304,0x2104,0x1e04,0x1a08
DAT 0x1c04,0x1e04,0x1e04, 0xff14
; I feel fantastic and I'm still alive.
DAT 0x200, 0x2104,0x2104,0x2104, 0x2304,0x2104,0x1e04,0x1a08
DAT 0x1c04,0x1e04,0x1e04, 0xff14
; While you're dying I'll be still alive.
DAT 0x200, 0x2104,0x2104,0x2104, 0x2304,0x2104,0x1e04,0x1a08
DAT 0x1c04,0x1e04,0x1e04, 0xff14
; And when you're dead I will be still alive.
DAT 0x200, 0x2104,0x2104,0x2104, 0x2304,0x2104,0x1e04,0x1a08
DAT 0x1c04,0x1e04,0x1e04, 0xff14
; Still alive. Still alive.
DAT 0x200, 0x1f04,0x2104,0x2104, 0xff14
DAT 0x1f04,0x1e04,0x1e04
DAT 0xff00


:bass
DAT 0xff24
DAT 0xff10
; Dum dum dum dum, dum dum dum dum
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04

DAT 0x0b04,0x1004,0x1304,0x1004, 0x0b04,0x1004,0x1304,0x1004
DAT 0x0904,0x1004,0x1304,0x0d04, 0x0904,0x1004,0x1304,0x0d04

DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04

DAT 0x0b04,0x1004,0x1304,0x1004, 0x0b04,0x1004,0x1304,0x1004
DAT 0x0904,0x1004,0x1304,0x0d04, 0x0904,0x1004,0x1304,0x0d04

; Bam ba-di dum.
DAT 0x0a04, 0x0e04, 0x1104, 0x1504, 0xff10

; Dun-dun. Dun-dun. Dun-dun. Dun-dun.
DAT 0x0c04,0x0c04,0xff08, 0x0704,0x0704,0xff08
DAT 0x0504,0x0504,0xff08, 0x0c04,0x0c04,0xff08
DAT 0x0c04,0x0c04,0xff08, 0x0704,0x0704,0xff08
DAT 0x0504,0x0504,0xff08, 0x0504,0x0504,0xff08

DAT 0x0a04,0x0a04,0x0a04,0x0a04, 0x0c04,0x0c04,0x0c04,0x0c04
DAT 0x0504,0x0504,0x0404,0x0404, 0x0204,0x0204,0xff08

DAT 0x0204,0xff04,0x0504,0xff04, 0x0404,0xff04,0x0604,0xff04

; Dum. Du-dum. Du-dum. Du-dum.
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04

; Dum dum dum dum, dum dum dum dum
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04

DAT 0x0b04,0x1004,0x1304,0x1004, 0x0b04,0x1004,0x1304,0x1004
DAT 0x0904,0x1004,0x1304,0x0d04, 0x0904,0x1004,0x1304,0x0d04

DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04

; Dum. Du-dum. Du-dum. Du-dum.
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04

; Dum, du-du-du-rum, bam, ba-ba-ba-ra-bam
DAT 0x1008,0xff04,0x1004, 0x1004,0x1204,0x1308
DAT 0x0908,0xff04,0x0904, 0x0904,0x0b04,0x0d04,0x0b04

; Baa-ba-ba-ba-ba-ba-ba
DAT 0x0a08,0x0a04,0x0a04, 0x0a04,0x0a04,0x0a04,0x0a04

; Dun-dun. Dun-dun. Dun-dun. Dun-dun.
DAT 0x1104,0x1104,0xff08, 0x0c04,0x0c04,0xff08
DAT 0x0a04,0x0a04,0xff08, 0x1104,0x1104,0xff08
DAT 0x1104,0x1104,0xff08, 0x0c04,0x0c04,0xff08
DAT 0x0a04,0x0a04,0xff08, 0x1104,0x1104,0xff08

; Dun-dun-dun-dun-dun-dun-dun-dun
DAT 0x0a04,0x0a04,0x0a04,0x0a04, 0x0c04,0x0c04,0x0c04,0x0c04
DAT 0x1104,0x1104,0x1004,0x1004, 0x0e04,0x0e04,0x0c04,0x0c04

; Boop. Beep. Boop. Beep.
DAT 0x0a04,0xff04, 0x1104,0xff04, 0x0904,0xff04, 0x1004,0xff04

; Dum. Du-dum. Du-dum. Du-dum.
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04

; Dum dum dum dum, dum dum dum dum
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04
DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04

DAT 0x0b04,0x1004,0x1304,0x1004, 0x0b04,0x1004,0x1304,0x1004
DAT 0x0904,0x1004,0x1304,0x0d04, 0x0904,0x1004,0x1304,0x0d04

DAT 0x0904,0x0e04,0x1204,0x0e04, 0x0b04,0x0e04,0x1204,0x0e04

; Dum. Du-dum. Du-dum. Du-dum.
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04

; Dum, du-du-du-rum, bam, ba-ba-ba-ra-bam
DAT 0x1008,0xff04,0x1004, 0x1004,0x1204,0x1308
DAT 0x0908,0xff04,0x0904, 0x0904,0x0b04,0x0d04,0x0b04

; Baa-ba-ba-ba-ba-ba-ba
DAT 0x0a08,0x0a04,0x0a04, 0x0a04,0x0a04,0x0a04,0x0a04

; Dun-dun. Dun-dun. Dun-dun. Dun-dun.
DAT 0x1104,0x1104,0xff08, 0x0c04,0x0c04,0xff08
DAT 0x0a04,0x0a04,0xff08, 0x1104,0x1104,0xff08
DAT 0x1104,0x1104,0xff08, 0x0c04,0x0c04,0xff08
DAT 0x0a04,0x0a04,0xff08, 0x1104,0x1104,0xff08

; Dun-dun-dun-dun-dun-dun-dun-dun
DAT 0x0a04,0x0a04,0x0a04,0x0a04, 0x0c04,0x0c04,0x0c04,0x0c04
DAT 0x1104,0x1104,0x1004,0x1004, 0x0e04,0x0e04,0x0c04,0x0c04

; Boop. Beep. Boop. Beep.
DAT 0x0a04,0xff04, 0x1104,0xff04, 0x0904,0xff04, 0x1004,0xff04

; Dum. Du-dum. Du-dum. Du-dum.
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08, 0x0b04
DAT 0x0e04,0xff08, 0x0e04, 0x0b04,0xff08

DAT 0xff00


; LYRICS
; Here's the ASCII data of the lyrics showing up, interspersed with special
; codes controlling the printing and drawing flow:
;  0x000a:  Newline (written as 10 for brevity)
;  0x01zz:  Draw image no. zz (refer to image index below)
;  0x0200:  Wait for signal from music generator (synchronization)
;  0x03zz:  Set delay length between subsequent character prints to zz*128
;  0xff00:  End of lyrics
:lyrics
DAT 0x100, 0x304
DAT "Forms FORM-29827281-12:", 10
DAT "Test Assessment Report", 10
DAT 10, 10, 0x308, 0x200
DAT "This was a triumph.", 10, 0x200, 0x30a
DAT "I'm making a note here:", 10, 0x200, 0x30c
DAT "HUGE SUCCESS.", 10, 0x200
DAT "It's hard to overstate", 10, 0x200, 0x310
DAT "my satisfaction.", 10, 0x200, 0x30a
DAT 0x101
DAT "Aperture Science", 10, 0x200
DAT "We do what we must", 10, 0x200
DAT "because we can.", 10, 0x200
DAT "For the good of all of us.", 10, 0x200
DAT 0x10a
DAT "Except the ones who are dead.", 10
DAT 10, 0x200
DAT 0x101
DAT "But there's no sense crying", 10
DAT "over every mistake.", 10, 0x200
DAT "You just keep on trying", 10
DAT "till you run out of cake.", 10, 0x200
DAT 0x102
DAT "And the Science gets done.", 10
DAT "And you make a neat gun.", 10
DAT 0x101
DAT "For the people who are", 10
DAT "still alive.", 10
DAT 10, 10, 10
DAT "Forms FORM-55551-5:", 10
DAT "Personnel File Addendum:", 10
DAT 10
DAT "Dear <<Subject Name Here>>,", 10
DAT 10, 0x200
DAT "I'm not even angry.", 10, 0x200
DAT "I'm being ",0x324,"so",0x30a," sincere right now.", 10, 0x200
DAT "Even though you ", 0x108, "broke my heart.", 10, 0x200
DAT "And killed me.", 10, 0x200
DAT 0x105
DAT "And tore me to pieces.", 10, 0x200
DAT "And threw every piece into ", 0x106, "a",10,"fire.", 10, 0x200
DAT "As they burned it hurt because", 10, 0x200
DAT 0x109
DAT "I was so happy for you!", 10, 0x200
DAT "Now these points of data", 10
DAT "make a beautiful line.", 10, 0x200
DAT "And we're out of beta.", 10, 0x200
DAT "We're releasing on time.", 10, 0x200
DAT 0x105
DAT "So I'm GLaD. I got burned.", 10, 0x200, 0x308
DAT 0x102
DAT "Think of all the things we",10,"learned", 10, 0x200, 0x309
DAT 0x101
DAT "for the people who are", 10
DAT "still alive.", 10, 0x30a
DAT 10, 10, 10
DAT "Forms FORM-55551-6:", 10
DAT "Personnel File Addendum",10,"Addendum:", 10
DAT 10
DAT "One last thing:", 10
DAT 10, 10, 0x200
DAT "Go ahead and leave me.", 10, 0x200
DAT "I think I prefer to stay inside.", 10, 0x200
DAT "Maybe you'll find someone else", 10, 0x200
DAT "to help you.", 10, 0x200
DAT "Maybe ", 0x103, "Black Mesa...", 10, 0x200
DAT "THAT WAS A JOKE. ",0x200,"FAT CHANCE.", 10, 0x200
DAT "Anyway, ", 0x104, "this cake is great.", 10, 0x200
DAT "It's so delicious and moist.", 10, 0x200
DAT 0x107
DAT "Look at me still talking", 10, 0x200
DAT 0x10a
DAT "when there's Science to do.", 10, 0x200
DAT 0x101
DAT "When I look out there,", 10, 0x200, 0x308
DAT "it makes me GLaD I'm not you.", 10, 0x200
DAT 0x102
DAT "I've experiments to run.", 10, 0x200
DAT 0x105
DAT "There is research to be done.", 10, 0x200
DAT 0x101
DAT "On the people who are", 10
DAT "still alive.", 10
DAT 10, 10, 10
DAT "PS: ",0x200,"And believe me I am", 10
DAT "still alive.", 10
DAT "PPS: ",0x200,"I'm doing Science and I'm", 10
DAT "still alive.", 10
DAT "PPPS: ",0x200,"I feel FANTASTIC and I'm", 10
DAT "still alive.", 10
DAT 10
DAT "FINAL THOUGHT:", 10, 0x200
DAT "While you're dying I'll be", 10
DAT "still alive.", 10
DAT 10
DAT "FINAL THOUGHT PS:", 10, 0x200
DAT "And when you're dead I will be", 10
DAT "still alive.", 10
DAT 10, 10, 0x200
DAT "STILL ALIVE", 10
DAT 10, 10, 10
DAT "THANK YOU FOR PARTICIPATING", 10
DAT "IN THIS", 10
DAT "ENRICHMENT CENTER ACTIVITY!!", 10
DAT 0xff00

:credits
DAT "Greetings to Reddit", 10
DAT "and the 0x10c", 10
DAT "community!", 10
DAT "I love you all.", 10
DAT 10, 10
DAT "Special thanks go to:", 10
DAT "Notch, for creating", 10
DAT "such amazing games", 10
DAT "and reintroducing", 10
DAT "retro programming", 10
DAT "for a new generation!", 10
DAT 10, 10
DAT "Thanks to Valve", 10
DAT "for creating Portal,", 10
DAT "an unforgettable", 10
DAT "classic of our time.", 10
DAT 10, 10
DAT "I would like to thank", 10
DAT "the users of my", 10
DAT "emulator, Saramakos", 10
DAT "DuoNoxSol and", 10
DAT "possibly others", 10
DAT "for their feedback", 10
DAT "and suggestions", 10
DAT "for improving the", 10
DAT "program.", 10
DAT 10, 10
DAT "Also, I'm grateful", 10
DAT "for all of my", 10
DAT "YouTube viewers,", 10
DAT "commenters and", 10
DAT "subscribers:", 10
DAT 10
DAT "rinsmaster", 10
DAT "B0G0MIP", 10
DAT "TheUnnamedGent", 10
DAT "Danny77uk", 10
DAT "saramakos", 10
DAT "DuoNoxSol", 10
DAT "NoobTrooper", 10
DAT "TheLiquider", 10
DAT "musacworld", 10
DAT "skiller931", 10
DAT "anikovegel", 10
DAT "MarcoBorner", 10
DAT "chickenmunt", 10
DAT "akureiokamii", 10
DAT "Bitwzyze", 10
DAT "h4emp3", 10
DAT "matthewburke47", 10
DAT "cherepb", 10
DAT "GDroidHacker", 10
DAT "truebones", 10
DAT "ladyxeona", 10
DAT "BC1337CoD", 10
DAT "trylleklovn", 10
DAT "anidude98", 10
DAT "hiromato", 10
DAT "JForceX", 10
DAT "imagetica", 10
DAT "Kisember6", 10
DAT "LunaVorax", 10
DAT "bryanliles", 10
DAT "chick3n999", 10
DAT "jsfyfield", 10
DAT "qualiabyte", 10
DAT "ObsidianHamr", 10
DAT "originalfa", 10
DAT "joetheplumber22", 10
DAT "Rhudgins7", 10
DAT "babygal95s9d", 10
DAT "brandonianhare", 10
DAT "TheZotant", 10
DAT "ashley4924j", 10
DAT "jackcursham", 10
DAT "sinandacceleration", 10
DAT "Stubenhocker1399", 10
DAT "zenteoxero", 10
DAT "got2nesa", 10
DAT "hsujohnhsu", 10
DAT "brandoncool12", 10
DAT "Arturpolis", 10
DAT "ismetteren", 10
DAT "cxgamer", 10
DAT "miniclipplay", 10
DAT "racmov", 10
DAT "failget", 10
DAT "chromosundrift", 10
DAT "sjidrummer47", 10
DAT "ekimsantos3000", 10
DAT "SonarWavePulse", 10
DAT "dekay9001", 10
DAT "TheGOchoaProductions", 10
DAT "noname4422", 10
DAT "ibanez4492", 10
DAT "Tovsky", 10
DAT "TheLegomaster616", 10
DAT 10
DAT "How do some of you", 10
DAT "even remember your", 10
DAT "usernames...", 10
DAT 10, 10
DAT "If you would like", 10
DAT "to run this program", 10
DAT "or play around with", 10
DAT "my emulator, look", 10
DAT "for the download", 10
DAT "link in the video", 10
DAT "description.", 10
DAT 10
DAT "Tell your friends!", 10
DAT 10, 10
DAT "Created by", 10
DAT "Benedek Vartok", 10
DAT 10, 10
DAT "THANKS FOR WATCHING!"
DAT 10, 10
DAT 0xff00


; IMAGES
; The images are stored as custom fontmaps, with a fixed screen map (the
; character codes at each position are constant).
; Since the images are shown at the same time as text, some ASCII characters
; must remain unchanged, such digits, characters and some punctuation.
; IMAGE INDEX:
;  0:  No image
;  1:  Aperture Science
;  2:  Atom
;  3:  Black Mesa
;  4:  Cake
;  5:  Explosion
;  6:  Fire
;  7:  GLaDOS
;  8:  Heart (broken)
;  9:  OK (Check Mark)
;  A:  Radiation
; RESERVED CHARACTERS:
;  0x20:      ' '
;  0x21:      '!'
;  0x27:      '''
;  0x2C:      ','
;  0x2D:      '-'
;  0x2E:      '.'
;  0x30-0x39: '0'-'9'
;  0x3A:      ':'
;  0x3C:      '<'
;  0x3E:      '>'
;  0x41-0x5A: 'A'-'Z'
;  0x61-0x7A: 'a'-'z'
:images
; No image
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
; Aperture Science
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x80c0,0xe0f0
DAT 0x00f8,0xfcfc
DAT 0xfefe,0xfe7e
DAT 0x3f9f,0xcfe7
DAT 0xf3f9,0xfcfe
DAT 0xfefe,0xfefe
DAT 0xfcfc,0xf8f0
DAT 0xf0e0,0xc080
DAT 0x0000,0x0000
DAT 0x00f0,0xfcfe
DAT 0xffff,0xffff
DAT 0x001f,0x0f07
DAT 0x0301,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0002
DAT 0x060e,0x1e3e
DAT 0x7efe,0xfefe
DAT 0xfefc,0xf000
DAT 0xfcf9,0xf3e7
DAT 0xcf9f,0x3f7f
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0xfefc,0xf9f3
DAT 0xe7cf,0x9f3f
DAT 0x000f,0x3f7f
DAT 0x7f7f,0x7f7e
DAT 0x7c78,0x7060
DAT 0x4000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x80c0
DAT 0xe0f0,0xf800
DAT 0xffff,0xffff
DAT 0x7f3f,0x0f00
DAT 0x0000,0x0000
DAT 0x0103,0x070f
DAT 0x0f1f,0x3f3f
DAT 0x7f7f,0x7f7f
DAT 0x7f3f,0x9fcf
DAT 0xe7f3,0xf9fc
DAT 0x7e7f,0x7f7f
DAT 0x3f3f,0x1f00
DAT 0x0f07,0x0301
DAT 0x0000,0x0000
; Atom
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x8080
DAT 0x8080,0x8080
DAT 0x00c0,0x3008
DAT 0x0402,0x0101
DAT 0x0101,0x0204
DAT 0x0830,0xc000
DAT 0x8080,0x8080
DAT 0x8080,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x7884
DAT 0x0201,0x0000
DAT 0x0000,0x0080
DAT 0xfd43,0x2122
DAT 0x1212,0x0c0c
DAT 0x0c0c,0x1212
DAT 0x2221,0x43fd
DAT 0x8000,0x0000
DAT 0x0000,0x0102
DAT 0x8478,0x0000
DAT 0x0000,0x0081
DAT 0x4224,0x1818
DAT 0x2442,0x81ff
DAT 0x0000,0x0000
DAT 0x0018,0x3c7e
DAT 0x7e3c,0x1800
DAT 0x0000,0x0000
DAT 0xff81,0x4224
DAT 0x1818,0x2442
DAT 0x8100,0x0000
DAT 0x0000,0x1e21
DAT 0x4080,0x0000
DAT 0x0000,0x0001
DAT 0xbfc2,0x8444
DAT 0x4848,0x3030
DAT 0x3030,0x4848
DAT 0x4484,0xc2bf
DAT 0x0100,0x0000
DAT 0x0000,0x8040
DAT 0x211e,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0101
DAT 0x0101,0x0101
DAT 0x0003,0x0c10
DAT 0x2040,0x8080
DAT 0x8080,0x4020
DAT 0x100c,0x0300
DAT 0x0101,0x0101
DAT 0x0101,0x0000
DAT 0x0000,0x0000
; Black Mesa
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x80c0,0xe070
DAT 0x3018,0x1c0c
DAT 0x0e06,0x0606
DAT 0x0303,0x0303
DAT 0x0303,0x0303
DAT 0x0606,0x060e
DAT 0x0c1c,0x1830
DAT 0x70e0,0xc080
DAT 0x0000,0x0000
DAT 0x00f0,0xfc1e
DAT 0x0701,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0107
DAT 0x1efc,0xf000
DAT 0xffff,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0xf8f8,0xf8f8
DAT 0xf8f8,0xf8f8
DAT 0xf8f8,0xf8f8
DAT 0xf8f8,0xf8f8
DAT 0xf8f8,0xf8f8
DAT 0xf0e0,0xc080
DAT 0x0000,0xffff
DAT 0x000f,0x3f78
DAT 0xe080,0x8080
DAT 0x8080,0x8080
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0x7f3f,0x0f00
DAT 0x0000,0x0000
DAT 0x0103,0x070f
DAT 0x0f1f,0x3f3f
DAT 0x7f7f,0x7f7f
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0x7f7f,0x7f7f
DAT 0x3f3f,0x1f0f
DAT 0x0f07,0x0301
DAT 0x0000,0x0000
; Cake
DAT 0x0020,0x60c0
DAT 0x8000,0x0000
DAT 0x8080,0x8080
DAT 0x0000,0x0000
DAT 0x00e0,0x3010
DAT 0x5030,0x181c
DAT 0x1733,0xe000
DAT 0x1010,0x1010
DAT 0x0808,0x0808
DAT 0x0404,0x0484
DAT 0x4242,0x2292
DAT 0x91c9,0xe5e5
DAT 0xf2f9,0xf9ff
DAT 0xff05,0x0911
DAT 0x2027,0x2c48
DAT 0x4848,0x8888
DAT 0x888c,0x8780
DAT 0x4040,0x2090
DAT 0x90c8,0xe4e4
DAT 0xf2f9,0xf9fc
DAT 0x7e3e,0x9f9f
DAT 0xcfe7,0xe7f3
DAT 0xf9fc,0xfcff
DAT 0xff00,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x007e,0x3f9f
DAT 0xcfcf,0xe7f3
DAT 0xf3f9,0xfcfc
DAT 0x7e3f,0x9f9f
DAT 0xcfe7,0xe7f3
DAT 0xf9fc,0xfcff
DAT 0xff00,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x007e,0x3f9f
DAT 0xcfcf,0xe7f3
DAT 0xf3f9,0xfcfc
DAT 0x7e7f,0x3f1f
DAT 0x1f0f,0x0707
DAT 0x0301,0x0100
DAT 0x0304,0x0810
DAT 0x2020,0x2040
DAT 0x4040,0x8080
DAT 0x8080,0x8080
DAT 0x407e,0x3f1f
DAT 0x1f0f,0x0707
DAT 0x0301,0x0100
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
; Explosion
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0006
DAT 0x1cf8,0xf0e0
DAT 0xc080,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0080
DAT 0xc0e0,0x3000
DAT 0x0000,0x0000
DAT 0x8080,0x8000
DAT 0x0000,0x0000
DAT 0x0000,0x0010
DAT 0x70e0,0xc7df
DAT 0xffff,0xfffe
DAT 0xfcf8,0xf0f8
DAT 0xfcfe,0xfff0
DAT 0xf8fc,0x3e0f
DAT 0x0300,0x0000
DAT 0x0000,0x0000
DAT 0x0001,0x0103
DAT 0x0307,0x070e
DAT 0x8e9e,0x9efe
DAT 0xfcfd,0xffff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xfffc,0xdc9c
DAT 0x8c04,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x80c0,0xe0e0
DAT 0xf0f9,0xfdff
DAT 0xffff,0xff7f
DAT 0x7fff,0xffff
DAT 0xffff,0x7fff
DAT 0xffff,0xff7f
DAT 0xffff,0xfbf3
DAT 0xe387,0x0604
DAT 0x0000,0x0000
DAT 0x0002,0x0303
DAT 0x0101,0x0101
DAT 0x0101,0x0000
DAT 0x0000,0x0000
DAT 0x00ff,0x7f1f
DAT 0x0701,0x0001
DAT 0x071f,0x0100
DAT 0x0000,0x0103
DAT 0x0707,0x0f1e
DAT 0x3830,0x60c0
; Fire
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x80f8,0xf0e0
DAT 0xc080,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x80c0,0xe0f0
DAT 0xf8fc,0xfeff
DAT 0xffff,0xffff
DAT 0xffff,0xfffe
DAT 0xfcf0,0xc000
DAT 0x0000,0xc080
DAT 0x0000,0x0000
DAT 0x0000,0xe0f0
DAT 0xf8fc,0xfc00
DAT 0x0000,0x3c7f
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0x7f3f,0x1f0f
DAT 0x0783,0xc0e0
DAT 0xf8fe,0xffff
DAT 0xfef8,0x0000
DAT 0x0000,0x8081
DAT 0x8387,0x878e
DAT 0x0c08,0x0000
DAT 0x0001,0x0307
DAT 0x0f1f,0x1f0f
DAT 0x0703,0x0100
DAT 0x0008,0x0c0e
DAT 0x0707,0x0707
DAT 0x8383,0x8381
DAT 0x8180,0x0000
DAT 0x0000,0xe3e7
DAT 0xe777,0x7777
DAT 0x7f7f,0x3f3f
DAT 0x3f3f,0x3f3f
DAT 0x1f1f,0x1e1e
DAT 0x1e1e,0x1e1e
DAT 0x1e1e,0x1f1f
DAT 0x3f3f,0x3f3f
DAT 0x3f3f,0x3f3f
DAT 0x3f39,0x0000
; GLaDOS
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x1e12,0x9272
DAT 0x7222,0xe343
DAT 0x2323,0x23e3
DAT 0xe323,0x2323
DAT 0x43e3,0x2272
DAT 0x7292,0x121e
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x00e0,0x1804
DAT 0x0201,0xc020
DAT 0x1008,0x0700
DAT 0x8080,0x405f
DAT 0x5f40,0x8080
DAT 0x0007,0x0810
DAT 0x20c0,0x0102
DAT 0x0418,0xe000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0xff00,0x0000
DAT 0x007e,0x8124
DAT 0x0000,0x3cc3
DAT 0x0000,0x183c
DAT 0x3c18,0x0000
DAT 0xc33c,0x0000
DAT 0x2481,0x7e00
DAT 0x0000,0x00ff
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0007,0x1820
DAT 0x4080,0x0304
DAT 0x0810,0xe000
DAT 0x0101,0x02fa
DAT 0xfa02,0x0101
DAT 0x00e0,0x1008
DAT 0x0403,0x8040
DAT 0x2018,0x0700
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x7848,0x494e
DAT 0x4c44,0xc7c2
DAT 0xc4c4,0xc4c7
DAT 0xc7c4,0xc4c4
DAT 0xc2c7,0x444c
DAT 0x4e49,0x4878
DAT 0x0000,0x0000
DAT 0x0000,0x0000
; Heart
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x00c0
DAT 0xe0f0,0xf0f8
DAT 0xf8fc,0xfc78
DAT 0xf8f8,0xf0f0
DAT 0xe080,0x0000
DAT 0x0000,0x0000
DAT 0xc0e0,0xe0f0
DAT 0xf8f8,0xf8f0
DAT 0xf0f0,0xe0c0
DAT 0x8000,0x0000
DAT 0x001e,0x7fff
DAT 0xffff,0xffff
DAT 0xfffc,0xf8f8
DAT 0xfcff,0xffff
DAT 0xffff,0xfee0
DAT 0x00c0,0xfcff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xffff,0xfcf0
DAT 0x0000,0x0000
DAT 0x031f,0x1fff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xff3f,0x0f03
DAT 0x0003,0x0f3f
DAT 0x7fff,0xffff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xff8f,0x0000
DAT 0x0000,0x0e1f
DAT 0x7fff,0xffff
DAT 0xff3f,0x0f03
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0103
DAT 0x0303,0x0307
DAT 0x0707,0x0707
DAT 0x0f0f,0x0f0f
DAT 0x1f1f,0x3f3e
DAT 0x3820,0x0000
DAT 0x0001,0x0703
DAT 0x0000,0x0000
DAT 0x0000,0x0000
; OK
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x00c0,0xe0f0
DAT 0xf8fc,0xfce0
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x80c0
DAT 0xf0f8,0xfcfe
DAT 0xffff,0xffff
DAT 0xffff,0xff7f
DAT 0x3f18,0x0000
DAT 0x0000,0x80c0
DAT 0xe0f0,0xf8fc
DAT 0xfef8,0xe0c0
DAT 0x8000,0x0000
DAT 0x00c0,0xe0f8
DAT 0xfcff,0xffff
DAT 0xffff,0xff7f
DAT 0x3f1f,0x0f07
DAT 0x0301,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0001
DAT 0x0103,0x070f
DAT 0x1f3f,0x7fff
DAT 0xffff,0xfcf8
DAT 0xfeff,0xffff
DAT 0x7f3f,0x1f07
DAT 0x0301,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0001
DAT 0x030f,0x1f3f
DAT 0x1f0f,0x0301
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
; Radiation
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x1878
DAT 0xfcfc,0xfcfc
DAT 0xfefe,0xfefe
DAT 0xfefe,0xfefe
DAT 0xfcfc,0xfcfc
DAT 0x7818,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0103,0x0f3f
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0x3f0f,0x0301
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0xe0e0,0xe0e0
DAT 0xe0e0,0xe0e0
DAT 0xe0e0,0xe0e0
DAT 0xe0e0,0xe080
DAT 0x0079,0xfdfd
DAT 0xfdfd,0x7900
DAT 0x80e0,0xe0e0
DAT 0xe0e0,0xe0e0
DAT 0xe0e0,0xe0e0
DAT 0xe0e0,0xe0e0
DAT 0x011f,0x7fff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xffff,0xff3f
DAT 0x0f02,0x0000
DAT 0x0000,0x020f
DAT 0x3fff,0xffff
DAT 0xffff,0xffff
DAT 0xffff,0xffff
DAT 0xff7f,0x1f01
DAT 0x0000,0x0000
DAT 0x0307,0x0f1f
DAT 0x1f3f,0x7f1f
DAT 0x0701,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0000
DAT 0x0000,0x0107
DAT 0x1f7f,0x3f1f
DAT 0x1f0f,0x0703
DAT 0x0000,0x0000

:freq_table  ; half-tone steps
; C2 -> C3
DAT  64,  69,  73,  78,  82,  87,  92,  98, 104, 110, 117, 123
; C3 -> B3
DAT 131, 139, 147, 156, 165, 175, 185, 196, 208, 220, 233, 247
; C4 -> B4
DAT 262, 277, 294, 311, 330, 349, 370, 392, 415, 440, 466, 494
; C5 -> B5
DAT 523, 554, 587, 622, 659, 698, 740, 784, 831, 880, 932, 988
; C6
DAT 1047


:palette
DAT 0x0000, 0x0ea0, 0x0ea0, 0x0ea0, 0x0ea0, 0x0ea0, 0x0ea0, 0x0ea0
DAT 0x0ea0, 0x0ea0, 0x0ea0, 0x0ea0, 0x0ea0, 0x0ea0, 0x0ea0, 0x0ea0


; hardware device table:
:monitor_n
DAT -1
:clock_n
DAT -1
:spkr_n
DAT -1


:fontmaps
